"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.features.feature_set_pb2
import qwak.feature_store.features.feature_set_state_pb2
import qwak.feature_store.features.feature_set_types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegisterFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Feature to register"""
    def __init__(
        self,
        *,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> None: ...

global___RegisterFeatureSetRequest = RegisterFeatureSetRequest

class RegisterFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """The newly created feature set"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___RegisterFeatureSetResponse = RegisterFeatureSetResponse

class UpdateFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """Feature set ID to update"""
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Feature set specifications to update"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id", "feature_set_spec", b"feature_set_spec"]) -> None: ...

global___UpdateFeatureSetRequest = UpdateFeatureSetRequest

class UpdateFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """The updated feature set"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___UpdateFeatureSetResponse = UpdateFeatureSetResponse

class GetFeatureSetByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """ID of feature to fetch"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___GetFeatureSetByIdRequest = GetFeatureSetByIdRequest

class GetFeatureSetByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetByIdResponse = GetFeatureSetByIdResponse

class GetFeatureSetByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Name of feature to fetch"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___GetFeatureSetByNameRequest = GetFeatureSetByNameRequest

class GetFeatureSetByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetByNameResponse = GetFeatureSetByNameResponse

class ListFeaturesetVersionsByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset to fetch versions for"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___ListFeaturesetVersionsByNameRequest = ListFeaturesetVersionsByNameRequest

class ListFeaturesetVersionsByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESETS_FIELD_NUMBER: builtins.int
    @property
    def featuresets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_pb2.FeaturesetInfo]:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        featuresets: collections.abc.Iterable[qwak.feature_store.features.feature_set_pb2.FeaturesetInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featuresets", b"featuresets"]) -> None: ...

global___ListFeaturesetVersionsByNameResponse = ListFeaturesetVersionsByNameResponse

class GetEnvToFeatureSetsMappingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetEnvToFeatureSetsMappingRequest = GetEnvToFeatureSetsMappingRequest

class GetEnvToFeatureSetsMappingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvToFeatureSetMappingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetList: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.feature_store.features.feature_set_pb2.FeatureSetList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENV_TO_FEATURE_SET_MAPPING_FIELD_NUMBER: builtins.int
    @property
    def env_to_feature_set_mapping(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.feature_store.features.feature_set_pb2.FeatureSetList]:
        """Mapping of environment to feature sets"""
    def __init__(
        self,
        *,
        env_to_feature_set_mapping: collections.abc.Mapping[builtins.str, qwak.feature_store.features.feature_set_pb2.FeatureSetList] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env_to_feature_set_mapping", b"env_to_feature_set_mapping"]) -> None: ...

global___GetEnvToFeatureSetsMappingResponse = GetEnvToFeatureSetsMappingResponse

class DeleteFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_ID_FIELD_NUMBER: builtins.int
    feature_set_id: builtins.str
    """ID of feature to delete"""
    def __init__(
        self,
        *,
        feature_set_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_id", b"feature_set_id"]) -> None: ...

global___DeleteFeatureSetRequest = DeleteFeatureSetRequest

class DeleteFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeatureSetResponse = DeleteFeatureSetResponse

class DeleteFeaturesetVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset"""
    featureset_version_number: builtins.int
    """Version number to delete"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        featureset_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "featureset_version_number", b"featureset_version_number"]) -> None: ...

global___DeleteFeaturesetVersionRequest = DeleteFeaturesetVersionRequest

class DeleteFeaturesetVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteFeaturesetVersionResponse = DeleteFeaturesetVersionResponse

class ListFeatureSetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListFeatureSetsRequest = ListFeatureSetsRequest

class ListFeatureSetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_FAMILIES_FIELD_NUMBER: builtins.int
    @property
    def feature_families(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.features.feature_set_pb2.FeatureSet]:
        """List of registered features"""
    def __init__(
        self,
        *,
        feature_families: collections.abc.Iterable[qwak.feature_store.features.feature_set_pb2.FeatureSet] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_families", b"feature_families"]) -> None: ...

global___ListFeatureSetsResponse = ListFeatureSetsResponse

class RunBatchFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name in order to run now batch job"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___RunBatchFeatureSetRequest = RunBatchFeatureSetRequest

class RunBatchFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RunBatchFeatureSetResponse = RunBatchFeatureSetResponse

class RunParquetBatchFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PARQUET_LOCATION_FIELD_NUMBER: builtins.int
    TIMESTAMP_COLUMN_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name in order to run now batch job"""
    parquet_location: builtins.str
    """The S3 location for the parquet file (can include `*` suffix if parquet is partitioned)"""
    timestamp_column: builtins.str
    """The name of the column in the parquet files that represent the data time dimension"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        parquet_location: builtins.str = ...,
        timestamp_column: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "parquet_location", b"parquet_location", "timestamp_column", b"timestamp_column"]) -> None: ...

global___RunParquetBatchFeatureSetRequest = RunParquetBatchFeatureSetRequest

class RunParquetBatchFeatureSetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RunParquetBatchFeatureSetResponse = RunParquetBatchFeatureSetResponse

class CreateUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature set name"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___CreateUploadURLRequest = CreateUploadURLRequest

class CreateUploadURLRequestV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    TRANSFORMATION_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Featureset unique identified"""
    @property
    def transformation(self) -> qwak.feature_store.features.feature_set_types_pb2.Transformation:
        """Transformation belonging to this featureset, used only for its type"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        transformation: qwak.feature_store.features.feature_set_types_pb2.Transformation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["transformation", b"transformation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "transformation", b"transformation"]) -> None: ...

global___CreateUploadURLRequestV1 = CreateUploadURLRequestV1

class CreateRealTimeFeatureExtractorUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Featureset unique identifier"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___CreateRealTimeFeatureExtractorUploadURLRequest = CreateRealTimeFeatureExtractorUploadURLRequest

class CreateUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url intended for the feature code upload"""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["upload_url", b"upload_url"]) -> None: ...

global___CreateUploadURLResponse = CreateUploadURLResponse

class UpdateFeatureSetStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeatureNamesStateEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___StateUpdate: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___StateUpdate | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEATURE_NAMES_STATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def feature_names_state(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___StateUpdate]:
        """Feature Set Names and state"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        feature_names_state: collections.abc.Mapping[builtins.str, global___StateUpdate] | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "feature_names_state", b"feature_names_state"]) -> None: ...

global___UpdateFeatureSetStateRequest = UpdateFeatureSetStateRequest

class StateUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_NAMES_STATE_FIELD_NUMBER: builtins.int
    feature_names_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """The state of the feature"""
    def __init__(
        self,
        *,
        feature_names_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_names_state", b"feature_names_state"]) -> None: ...

global___StateUpdate = StateUpdate

class UpdateFeatureSetStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateFeatureSetStateResponse = UpdateFeatureSetStateResponse

class GetFeatureSetStateByNameRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature Set Name"""
    run_id: builtins.int
    """Running Id. Run-Id with Non-scheduled application will be 0 by default"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        run_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "run_id", b"run_id"]) -> None: ...

global___GetFeatureSetStateByNameRequest = GetFeatureSetStateByNameRequest

class GetFeatureSetStateByNameResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_STATE_FIELD_NUMBER: builtins.int
    feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType
    """Fetched state"""
    def __init__(
        self,
        *,
        feature_set_state: qwak.feature_store.features.feature_set_state_pb2.FeatureSetLastExecutionState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_state", b"feature_set_state"]) -> None: ...

global___GetFeatureSetStateByNameResponse = GetFeatureSetStateByNameResponse

class GetFeatureSetStateByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """Feature Set Name"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___GetFeatureSetStateByIdRequest = GetFeatureSetStateByIdRequest

class GetFeatureSetStateByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_FIELD_NUMBER: builtins.int
    @property
    def feature_set(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSet:
        """Fetched feature set object"""
    def __init__(
        self,
        *,
        feature_set: qwak.feature_store.features.feature_set_pb2.FeatureSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set", b"feature_set"]) -> None: ...

global___GetFeatureSetStateByIdResponse = GetFeatureSetStateByIdResponse

class PauseFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___PauseFeaturesetRequest = PauseFeaturesetRequest

class PauseFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PauseFeaturesetResponse = PauseFeaturesetResponse

class ResumeFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___ResumeFeaturesetRequest = ResumeFeaturesetRequest

class ResumeFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ResumeFeaturesetResponse = ResumeFeaturesetResponse

class GetFeaturesetSchedulingStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___GetFeaturesetSchedulingStateRequest = GetFeaturesetSchedulingStateRequest

class GetFeaturesetSchedulingStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    state: qwak.feature_store.features.feature_set_pb2.FeaturesetSchedulingState.ValueType
    def __init__(
        self,
        *,
        state: qwak.feature_store.features.feature_set_pb2.FeaturesetSchedulingState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___GetFeaturesetSchedulingStateResponse = GetFeaturesetSchedulingStateResponse

class SetActiveFeaturesetVersionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_VERSION_NUMBER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    """Name of the Featureset"""
    featureset_version_number: builtins.int
    """Version number to set as active"""
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        featureset_version_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "featureset_version_number", b"featureset_version_number"]) -> None: ...

global___SetActiveFeaturesetVersionRequest = SetActiveFeaturesetVersionRequest

class SetActiveFeaturesetVersionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetActiveFeaturesetVersionResponse = SetActiveFeaturesetVersionResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/kube_deployment_captain/batch_job.proto\x12\x1cqwak.kube.deployment.captain\"\xdb\x02\n\x1cListInferenceJobFilesRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x16\n\x0e\x64irectory_path\x18\x02 \x01(\t\x12\x18\n\x0ctoken_secret\x18\x03 \x01(\tB\x02\x18\x01\x12\x19\n\rsecret_secret\x18\x04 \x01(\tB\x02\x18\x01\x12\x1a\n\x12secret_service_url\x18\x05 \x01(\t\x12\x14\n\x08role_arn\x18\x06 \x01(\tB\x02\x18\x01\x12G\n\x0f\x61ws_credentials\x18\x07 \x01(\x0b\x32,.qwak.kube.deployment.captain.AwsCredentialsH\x00\x12G\n\x0fgcp_credentials\x18\x08 \x01(\x0b\x32,.qwak.kube.deployment.captain.GcpCredentialsH\x00\x42\x1a\n\x18\x63loud_client_credentials\"O\n\x0e\x41wsCredentials\x12\x10\n\x08role_arn\x18\x01 \x01(\t\x12\x14\n\x0ctoken_secret\x18\x02 \x01(\t\x12\x15\n\rsecret_secret\x18\x04 \x01(\t\"9\n\x0eGcpCredentials\x12\'\n\x1fservice_account_json_key_secret\x18\x01 \x01(\t\"\\\n\x1dListInferenceJobFilesResponse\x12\x12\n\nfile_names\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\t\"\xf0\x01\n\"CreateInferenceTaskExecutorRequest\x12\x63\n\x1btask_executor_configuration\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.TaskExecutorConfigurationMessage\x12\x65\n\x1cinference_task_configuration\x18\x02 \x01(\x0b\x32?.qwak.kube.deployment.captain.InferenceTaskConfigurationMessage\"\x89\x01\n\x1aPrepareInferenceJobRequest\x12k\n#inference_job_configuration_message\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.InferenceJobConfigurationMessage\"F\n\x1bPrepareInferenceJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\x90\x04\n TaskExecutorConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\x12G\n\x10model_identifier\x18\x05 \x01(\x0b\x32-.qwak.kube.deployment.captain.ModelIdentifier\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x15\n\rbackoff_limit\x18\x07 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x08 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\t \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x0c \x01(\t\x12\x41\n\x08job_size\x18\r \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x17\n\x0fpurchase_option\x18\x0e \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0f \x01(\t\x12%\n\x1d\x63ustom_service_account_secret\x18\x10 \x01(\t\"q\n InferenceJobConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x03 \x01(\t\"`\n\x0fModelIdentifier\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\x8c\x04\n!InferenceTaskConfigurationMessage\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x10\n\x08\x66ilepath\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x44\n\x0finput_file_type\x18\x05 \x01(\x0e\x32+.qwak.kube.deployment.captain.InputFileType\x12\x46\n\x10output_file_type\x18\x06 \x01(\x0e\x32,.qwak.kube.deployment.captain.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x07 \x01(\t\x12\x15\n\rsecret_secret\x18\x08 \x01(\t\x12\x43\n\nparameters\x18\t \x03(\x0b\x32/.qwak.kube.deployment.captain.BatchJobParameter\x12\x43\n\x0e\x63loud_provider\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.CloudProvider\x12\'\n\x1fservice_account_json_key_secret\x18\x0b \x01(\t\x12\x1a\n\x12is_point_file_path\x18\x0c \x01(\x08\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n#CleanInferenceTasksExecutorsRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\"O\n$CleanInferenceTasksExecutorsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"X\n!CleanInferenceTaskExecutorRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\"M\n\"CleanInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"N\n#CreateInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xf7\x02\n\x1eStartInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12\x0f\n\x03\x63pu\x18\x05 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x06 \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\x07 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x11\n\texecutors\x18\x08 \x01(\x05\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x41\n\x08job_size\x18\n \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x12\n\nmodel_uuid\x18\x0b \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0c \x01(\t\"!\n\x1fStartInferenceJobWarmupResponse\"p\n\x1f\x43\x61ncelInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\"\n CancelInferenceJobWarmupResponse\"\xd5\x01\n\x11\x42\x61tchJobResources\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x02 \x01(\x02\x12\x15\n\rmemory_amount\x18\x03 \x01(\x05\x12\x41\n\x0cmemory_units\x18\x04 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApi\x12\x41\n\rgpu_resources\x18\x05 \x01(\x0b\x32*.qwak.kube.deployment.captain.GpuResources\"[\n\x0cGpuResources\x12\x37\n\x08gpu_type\x18\x01 \x01(\x0e\x32%.qwak.kube.deployment.captain.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05*:\n\rMemoryUnitApi\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x90\x02\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*=\n\rCloudProvider\x12\x1a\n\x16UNKNOWN_CLOUD_PROVIDER\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_MEMORYUNITAPI = DESCRIPTOR.enum_types_by_name['MemoryUnitApi']
MemoryUnitApi = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNITAPI)
_INPUTFILETYPE = DESCRIPTOR.enum_types_by_name['InputFileType']
InputFileType = enum_type_wrapper.EnumTypeWrapper(_INPUTFILETYPE)
_OUTPUTFILETYPE = DESCRIPTOR.enum_types_by_name['OutputFileType']
OutputFileType = enum_type_wrapper.EnumTypeWrapper(_OUTPUTFILETYPE)
_GPUTYPE = DESCRIPTOR.enum_types_by_name['GpuType']
GpuType = enum_type_wrapper.EnumTypeWrapper(_GPUTYPE)
_CLOUDPROVIDER = DESCRIPTOR.enum_types_by_name['CloudProvider']
CloudProvider = enum_type_wrapper.EnumTypeWrapper(_CLOUDPROVIDER)
UNKNOWN_MEMORY_UNIT = 0
MIB = 1
GIB = 2
UNDEFINED_INPUT_FILE_TYPE = 0
CSV_INPUT_FILE_TYPE = 1
FEATHER_INPUT_FILE_TYPE = 2
PARQUET_INPUT_FILE_TYPE = 3
UNDEFINED_OUTPUT_FILE_TYPE = 0
CSV_OUTPUT_FILE_TYPE = 1
FEATHER_OUTPUT_FILE_TYPE = 2
PARQUET_OUTPUT_FILE_TYPE = 3
INVALID_GPU = 0
NVIDIA_K80 = 1
NVIDIA_V100 = 2
NVIDIA_A100 = 3
NVIDIA_T4 = 4
NVIDIA_A10G = 5
NVIDIA_L4 = 6
NVIDIA_T4_1_4_15 = 7
NVIDIA_T4_1_8_30 = 8
NVIDIA_T4_1_16_60 = 9
NVIDIA_A100_80GB_8_96_1360 = 10
NVIDIA_V100_1_8_52 = 11
NVIDIA_V100_4_32_208 = 12
UNKNOWN_CLOUD_PROVIDER = 0
AWS = 1
GCP = 2


_LISTINFERENCEJOBFILESREQUEST = DESCRIPTOR.message_types_by_name['ListInferenceJobFilesRequest']
_AWSCREDENTIALS = DESCRIPTOR.message_types_by_name['AwsCredentials']
_GCPCREDENTIALS = DESCRIPTOR.message_types_by_name['GcpCredentials']
_LISTINFERENCEJOBFILESRESPONSE = DESCRIPTOR.message_types_by_name['ListInferenceJobFilesResponse']
_CREATEINFERENCETASKEXECUTORREQUEST = DESCRIPTOR.message_types_by_name['CreateInferenceTaskExecutorRequest']
_PREPAREINFERENCEJOBREQUEST = DESCRIPTOR.message_types_by_name['PrepareInferenceJobRequest']
_PREPAREINFERENCEJOBRESPONSE = DESCRIPTOR.message_types_by_name['PrepareInferenceJobResponse']
_TASKEXECUTORCONFIGURATIONMESSAGE = DESCRIPTOR.message_types_by_name['TaskExecutorConfigurationMessage']
_INFERENCEJOBCONFIGURATIONMESSAGE = DESCRIPTOR.message_types_by_name['InferenceJobConfigurationMessage']
_MODELIDENTIFIER = DESCRIPTOR.message_types_by_name['ModelIdentifier']
_INFERENCETASKCONFIGURATIONMESSAGE = DESCRIPTOR.message_types_by_name['InferenceTaskConfigurationMessage']
_BATCHJOBPARAMETER = DESCRIPTOR.message_types_by_name['BatchJobParameter']
_CLEANINFERENCETASKSEXECUTORSREQUEST = DESCRIPTOR.message_types_by_name['CleanInferenceTasksExecutorsRequest']
_CLEANINFERENCETASKSEXECUTORSRESPONSE = DESCRIPTOR.message_types_by_name['CleanInferenceTasksExecutorsResponse']
_CLEANINFERENCETASKEXECUTORREQUEST = DESCRIPTOR.message_types_by_name['CleanInferenceTaskExecutorRequest']
_CLEANINFERENCETASKEXECUTORRESPONSE = DESCRIPTOR.message_types_by_name['CleanInferenceTaskExecutorResponse']
_CREATEINFERENCETASKEXECUTORRESPONSE = DESCRIPTOR.message_types_by_name['CreateInferenceTaskExecutorResponse']
_STARTINFERENCEJOBWARMUPREQUEST = DESCRIPTOR.message_types_by_name['StartInferenceJobWarmupRequest']
_STARTINFERENCEJOBWARMUPRESPONSE = DESCRIPTOR.message_types_by_name['StartInferenceJobWarmupResponse']
_CANCELINFERENCEJOBWARMUPREQUEST = DESCRIPTOR.message_types_by_name['CancelInferenceJobWarmupRequest']
_CANCELINFERENCEJOBWARMUPRESPONSE = DESCRIPTOR.message_types_by_name['CancelInferenceJobWarmupResponse']
_BATCHJOBRESOURCES = DESCRIPTOR.message_types_by_name['BatchJobResources']
_GPURESOURCES = DESCRIPTOR.message_types_by_name['GpuResources']
ListInferenceJobFilesRequest = _reflection.GeneratedProtocolMessageType('ListInferenceJobFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINFERENCEJOBFILESREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.ListInferenceJobFilesRequest)
  })
_sym_db.RegisterMessage(ListInferenceJobFilesRequest)

AwsCredentials = _reflection.GeneratedProtocolMessageType('AwsCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSCREDENTIALS,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.AwsCredentials)
  })
_sym_db.RegisterMessage(AwsCredentials)

GcpCredentials = _reflection.GeneratedProtocolMessageType('GcpCredentials', (_message.Message,), {
  'DESCRIPTOR' : _GCPCREDENTIALS,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.GcpCredentials)
  })
_sym_db.RegisterMessage(GcpCredentials)

ListInferenceJobFilesResponse = _reflection.GeneratedProtocolMessageType('ListInferenceJobFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINFERENCEJOBFILESRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.ListInferenceJobFilesResponse)
  })
_sym_db.RegisterMessage(ListInferenceJobFilesResponse)

CreateInferenceTaskExecutorRequest = _reflection.GeneratedProtocolMessageType('CreateInferenceTaskExecutorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINFERENCETASKEXECUTORREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CreateInferenceTaskExecutorRequest)
  })
_sym_db.RegisterMessage(CreateInferenceTaskExecutorRequest)

PrepareInferenceJobRequest = _reflection.GeneratedProtocolMessageType('PrepareInferenceJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREINFERENCEJOBREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.PrepareInferenceJobRequest)
  })
_sym_db.RegisterMessage(PrepareInferenceJobRequest)

PrepareInferenceJobResponse = _reflection.GeneratedProtocolMessageType('PrepareInferenceJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPAREINFERENCEJOBRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.PrepareInferenceJobResponse)
  })
_sym_db.RegisterMessage(PrepareInferenceJobResponse)

TaskExecutorConfigurationMessage = _reflection.GeneratedProtocolMessageType('TaskExecutorConfigurationMessage', (_message.Message,), {
  'DESCRIPTOR' : _TASKEXECUTORCONFIGURATIONMESSAGE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.TaskExecutorConfigurationMessage)
  })
_sym_db.RegisterMessage(TaskExecutorConfigurationMessage)

InferenceJobConfigurationMessage = _reflection.GeneratedProtocolMessageType('InferenceJobConfigurationMessage', (_message.Message,), {
  'DESCRIPTOR' : _INFERENCEJOBCONFIGURATIONMESSAGE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.InferenceJobConfigurationMessage)
  })
_sym_db.RegisterMessage(InferenceJobConfigurationMessage)

ModelIdentifier = _reflection.GeneratedProtocolMessageType('ModelIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _MODELIDENTIFIER,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.ModelIdentifier)
  })
_sym_db.RegisterMessage(ModelIdentifier)

InferenceTaskConfigurationMessage = _reflection.GeneratedProtocolMessageType('InferenceTaskConfigurationMessage', (_message.Message,), {
  'DESCRIPTOR' : _INFERENCETASKCONFIGURATIONMESSAGE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.InferenceTaskConfigurationMessage)
  })
_sym_db.RegisterMessage(InferenceTaskConfigurationMessage)

BatchJobParameter = _reflection.GeneratedProtocolMessageType('BatchJobParameter', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBPARAMETER,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.BatchJobParameter)
  })
_sym_db.RegisterMessage(BatchJobParameter)

CleanInferenceTasksExecutorsRequest = _reflection.GeneratedProtocolMessageType('CleanInferenceTasksExecutorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEANINFERENCETASKSEXECUTORSREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CleanInferenceTasksExecutorsRequest)
  })
_sym_db.RegisterMessage(CleanInferenceTasksExecutorsRequest)

CleanInferenceTasksExecutorsResponse = _reflection.GeneratedProtocolMessageType('CleanInferenceTasksExecutorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLEANINFERENCETASKSEXECUTORSRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CleanInferenceTasksExecutorsResponse)
  })
_sym_db.RegisterMessage(CleanInferenceTasksExecutorsResponse)

CleanInferenceTaskExecutorRequest = _reflection.GeneratedProtocolMessageType('CleanInferenceTaskExecutorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEANINFERENCETASKEXECUTORREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CleanInferenceTaskExecutorRequest)
  })
_sym_db.RegisterMessage(CleanInferenceTaskExecutorRequest)

CleanInferenceTaskExecutorResponse = _reflection.GeneratedProtocolMessageType('CleanInferenceTaskExecutorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CLEANINFERENCETASKEXECUTORRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CleanInferenceTaskExecutorResponse)
  })
_sym_db.RegisterMessage(CleanInferenceTaskExecutorResponse)

CreateInferenceTaskExecutorResponse = _reflection.GeneratedProtocolMessageType('CreateInferenceTaskExecutorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINFERENCETASKEXECUTORRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CreateInferenceTaskExecutorResponse)
  })
_sym_db.RegisterMessage(CreateInferenceTaskExecutorResponse)

StartInferenceJobWarmupRequest = _reflection.GeneratedProtocolMessageType('StartInferenceJobWarmupRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINFERENCEJOBWARMUPREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.StartInferenceJobWarmupRequest)
  })
_sym_db.RegisterMessage(StartInferenceJobWarmupRequest)

StartInferenceJobWarmupResponse = _reflection.GeneratedProtocolMessageType('StartInferenceJobWarmupResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTINFERENCEJOBWARMUPRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.StartInferenceJobWarmupResponse)
  })
_sym_db.RegisterMessage(StartInferenceJobWarmupResponse)

CancelInferenceJobWarmupRequest = _reflection.GeneratedProtocolMessageType('CancelInferenceJobWarmupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELINFERENCEJOBWARMUPREQUEST,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CancelInferenceJobWarmupRequest)
  })
_sym_db.RegisterMessage(CancelInferenceJobWarmupRequest)

CancelInferenceJobWarmupResponse = _reflection.GeneratedProtocolMessageType('CancelInferenceJobWarmupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELINFERENCEJOBWARMUPRESPONSE,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.CancelInferenceJobWarmupResponse)
  })
_sym_db.RegisterMessage(CancelInferenceJobWarmupResponse)

BatchJobResources = _reflection.GeneratedProtocolMessageType('BatchJobResources', (_message.Message,), {
  'DESCRIPTOR' : _BATCHJOBRESOURCES,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.BatchJobResources)
  })
_sym_db.RegisterMessage(BatchJobResources)

GpuResources = _reflection.GeneratedProtocolMessageType('GpuResources', (_message.Message,), {
  'DESCRIPTOR' : _GPURESOURCES,
  '__module__' : 'qwak.kube_deployment_captain.batch_job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.GpuResources)
  })
_sym_db.RegisterMessage(GpuResources)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _MODELIDENTIFIER.fields_by_name['branch_id']._options = None
  _MODELIDENTIFIER.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _MEMORYUNITAPI._serialized_start=3704
  _MEMORYUNITAPI._serialized_end=3762
  _INPUTFILETYPE._serialized_start=3765
  _INPUTFILETYPE._serialized_end=3894
  _OUTPUTFILETYPE._serialized_start=3897
  _OUTPUTFILETYPE._serialized_end=4031
  _GPUTYPE._serialized_start=4034
  _GPUTYPE._serialized_end=4306
  _CLOUDPROVIDER._serialized_start=4308
  _CLOUDPROVIDER._serialized_end=4369
  _LISTINFERENCEJOBFILESREQUEST._serialized_start=79
  _LISTINFERENCEJOBFILESREQUEST._serialized_end=426
  _AWSCREDENTIALS._serialized_start=428
  _AWSCREDENTIALS._serialized_end=507
  _GCPCREDENTIALS._serialized_start=509
  _GCPCREDENTIALS._serialized_end=566
  _LISTINFERENCEJOBFILESRESPONSE._serialized_start=568
  _LISTINFERENCEJOBFILESRESPONSE._serialized_end=660
  _CREATEINFERENCETASKEXECUTORREQUEST._serialized_start=663
  _CREATEINFERENCETASKEXECUTORREQUEST._serialized_end=903
  _PREPAREINFERENCEJOBREQUEST._serialized_start=906
  _PREPAREINFERENCEJOBREQUEST._serialized_end=1043
  _PREPAREINFERENCEJOBRESPONSE._serialized_start=1045
  _PREPAREINFERENCEJOBRESPONSE._serialized_end=1115
  _TASKEXECUTORCONFIGURATIONMESSAGE._serialized_start=1118
  _TASKEXECUTORCONFIGURATIONMESSAGE._serialized_end=1646
  _INFERENCEJOBCONFIGURATIONMESSAGE._serialized_start=1648
  _INFERENCEJOBCONFIGURATIONMESSAGE._serialized_end=1761
  _MODELIDENTIFIER._serialized_start=1763
  _MODELIDENTIFIER._serialized_end=1859
  _INFERENCETASKCONFIGURATIONMESSAGE._serialized_start=1862
  _INFERENCETASKCONFIGURATIONMESSAGE._serialized_end=2386
  _BATCHJOBPARAMETER._serialized_start=2388
  _BATCHJOBPARAMETER._serialized_end=2435
  _CLEANINFERENCETASKSEXECUTORSREQUEST._serialized_start=2437
  _CLEANINFERENCETASKSEXECUTORSREQUEST._serialized_end=2500
  _CLEANINFERENCETASKSEXECUTORSRESPONSE._serialized_start=2502
  _CLEANINFERENCETASKSEXECUTORSRESPONSE._serialized_end=2581
  _CLEANINFERENCETASKEXECUTORREQUEST._serialized_start=2583
  _CLEANINFERENCETASKEXECUTORREQUEST._serialized_end=2671
  _CLEANINFERENCETASKEXECUTORRESPONSE._serialized_start=2673
  _CLEANINFERENCETASKEXECUTORRESPONSE._serialized_end=2750
  _CREATEINFERENCETASKEXECUTORRESPONSE._serialized_start=2752
  _CREATEINFERENCETASKEXECUTORRESPONSE._serialized_end=2830
  _STARTINFERENCEJOBWARMUPREQUEST._serialized_start=2833
  _STARTINFERENCEJOBWARMUPREQUEST._serialized_end=3208
  _STARTINFERENCEJOBWARMUPRESPONSE._serialized_start=3210
  _STARTINFERENCEJOBWARMUPRESPONSE._serialized_end=3243
  _CANCELINFERENCEJOBWARMUPREQUEST._serialized_start=3245
  _CANCELINFERENCEJOBWARMUPREQUEST._serialized_end=3357
  _CANCELINFERENCEJOBWARMUPRESPONSE._serialized_start=3359
  _CANCELINFERENCEJOBWARMUPRESPONSE._serialized_end=3393
  _BATCHJOBRESOURCES._serialized_start=3396
  _BATCHJOBRESOURCES._serialized_end=3609
  _GPURESOURCES._serialized_start=3611
  _GPURESOURCES._serialized_end=3702
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.automation.v1.common_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Trigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEDULED_TRIGGER_FIELD_NUMBER: builtins.int
    METRIC_BASED_TRIGGER_FIELD_NUMBER: builtins.int
    NONE_TRIGGER_FIELD_NUMBER: builtins.int
    ON_BOARDING_TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def scheduled_trigger(self) -> global___ScheduledTrigger: ...
    @property
    def metric_based_trigger(self) -> global___MetricBasedTrigger: ...
    @property
    def none_trigger(self) -> global___NoneTrigger: ...
    @property
    def on_boarding_trigger(self) -> global___OnBoardingTrigger: ...
    def __init__(
        self,
        *,
        scheduled_trigger: global___ScheduledTrigger | None = ...,
        metric_based_trigger: global___MetricBasedTrigger | None = ...,
        none_trigger: global___NoneTrigger | None = ...,
        on_boarding_trigger: global___OnBoardingTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric_based_trigger", b"metric_based_trigger", "none_trigger", b"none_trigger", "on_boarding_trigger", b"on_boarding_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger", b"trigger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_based_trigger", b"metric_based_trigger", "none_trigger", b"none_trigger", "on_boarding_trigger", b"on_boarding_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger", b"trigger"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["trigger", b"trigger"]) -> typing_extensions.Literal["scheduled_trigger", "metric_based_trigger", "none_trigger", "on_boarding_trigger"] | None: ...

global___Trigger = Trigger

class ScheduledTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRON_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    cron: builtins.str
    """Cron defined schedule"""
    interval: builtins.str
    """Cron interval schedule"""
    def __init__(
        self,
        *,
        cron: builtins.str = ...,
        interval: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cron", b"cron", "interval", b"interval", "schedule", b"schedule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cron", b"cron", "interval", b"interval", "schedule", b"schedule"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["schedule", b"schedule"]) -> typing_extensions.Literal["cron", "interval"] | None: ...

global___ScheduledTrigger = ScheduledTrigger

class MetricBasedTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    METRIC_FIELD_NUMBER: builtins.int
    THRESHOLD_DIRECTION_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    OVERRIDE_CRON_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def metric(self) -> qwak.automation.v1.common_pb2.Metric: ...
    threshold_direction: qwak.automation.v1.common_pb2.MetricThresholdDirection.ValueType
    threshold: builtins.str
    override_cron: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        metric: qwak.automation.v1.common_pb2.Metric | None = ...,
        threshold_direction: qwak.automation.v1.common_pb2.MetricThresholdDirection.ValueType = ...,
        threshold: builtins.str = ...,
        override_cron: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metric", b"metric"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric", b"metric", "name", b"name", "override_cron", b"override_cron", "threshold", b"threshold", "threshold_direction", b"threshold_direction"]) -> None: ...

global___MetricBasedTrigger = MetricBasedTrigger

class NoneTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoneTrigger = NoneTrigger

class OnBoardingTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___OnBoardingTrigger = OnBoardingTrigger



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/authenticated_user/v1/authenticated_user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import details_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_details__pb2
from _qwak_proto.qwak.administration.authenticated_user.v1 import credentials_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_credentials__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJqwak/administration/authenticated_user/v1/authenticated_user_service.proto\x12)qwak.administration.authenticated_user.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x37qwak/administration/authenticated_user/v1/details.proto\x1a;qwak/administration/authenticated_user/v1/credentials.proto\"\x13\n\x11GetDetailsRequest\"\xae\x01\n\x12GetDetailsResponse\x12\x44\n\x04user\x18\x01 \x01(\x0b\x32\x36.qwak.administration.authenticated_user.v1.UserDetails\x12R\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32=.qwak.administration.authenticated_user.v1.EnvironmentDetails\"\x1e\n\x1cGetEnvironmentDetailsRequest\"s\n\x1dGetEnvironmentDetailsResponse\x12R\n\x0b\x65nvironment\x18\x01 \x01(\x0b\x32=.qwak.administration.authenticated_user.v1.EnvironmentDetails\"I\n\x1aGetCloudCredentialsRequest\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"u\n\x1bGetCloudCredentialsResponse\x12V\n\x11\x63loud_credentials\x18\x01 \x01(\x0b\x32;.qwak.administration.authenticated_user.v1.CloudCredentials2\xf3\x03\n\x11\x41uthenticatedUser\x12\x89\x01\n\nGetDetails\x12<.qwak.administration.authenticated_user.v1.GetDetailsRequest\x1a=.qwak.administration.authenticated_user.v1.GetDetailsResponse\x12\xaa\x01\n\x15GetEnvironmentDetails\x12G.qwak.administration.authenticated_user.v1.GetEnvironmentDetailsRequest\x1aH.qwak.administration.authenticated_user.v1.GetEnvironmentDetailsResponse\x12\xa4\x01\n\x13GetCloudCredentials\x12\x45.qwak.administration.authenticated_user.v1.GetCloudCredentialsRequest\x1a\x46.qwak.administration.authenticated_user.v1.GetCloudCredentialsResponseBN\n4com.qwak.ai.administration.api.authenticated_user.v1P\x01Z\x14.;authenticated_userb\x06proto3')



_GETDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetDetailsRequest']
_GETDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetDetailsResponse']
_GETENVIRONMENTDETAILSREQUEST = DESCRIPTOR.message_types_by_name['GetEnvironmentDetailsRequest']
_GETENVIRONMENTDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['GetEnvironmentDetailsResponse']
_GETCLOUDCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['GetCloudCredentialsRequest']
_GETCLOUDCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['GetCloudCredentialsResponse']
GetDetailsRequest = _reflection.GeneratedProtocolMessageType('GetDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDETAILSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetDetailsRequest)
  })
_sym_db.RegisterMessage(GetDetailsRequest)

GetDetailsResponse = _reflection.GeneratedProtocolMessageType('GetDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDETAILSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetDetailsResponse)
  })
_sym_db.RegisterMessage(GetDetailsResponse)

GetEnvironmentDetailsRequest = _reflection.GeneratedProtocolMessageType('GetEnvironmentDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTDETAILSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetEnvironmentDetailsRequest)
  })
_sym_db.RegisterMessage(GetEnvironmentDetailsRequest)

GetEnvironmentDetailsResponse = _reflection.GeneratedProtocolMessageType('GetEnvironmentDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENVIRONMENTDETAILSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetEnvironmentDetailsResponse)
  })
_sym_db.RegisterMessage(GetEnvironmentDetailsResponse)

GetCloudCredentialsRequest = _reflection.GeneratedProtocolMessageType('GetCloudCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDCREDENTIALSREQUEST,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetCloudCredentialsRequest)
  })
_sym_db.RegisterMessage(GetCloudCredentialsRequest)

GetCloudCredentialsResponse = _reflection.GeneratedProtocolMessageType('GetCloudCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDCREDENTIALSRESPONSE,
  '__module__' : 'qwak.administration.authenticated_user.v1.authenticated_user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.authenticated_user.v1.GetCloudCredentialsResponse)
  })
_sym_db.RegisterMessage(GetCloudCredentialsResponse)

_AUTHENTICATEDUSER = DESCRIPTOR.services_by_name['AuthenticatedUser']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4com.qwak.ai.administration.api.authenticated_user.v1P\001Z\024.;authenticated_user'
  _GETDETAILSREQUEST._serialized_start=271
  _GETDETAILSREQUEST._serialized_end=290
  _GETDETAILSRESPONSE._serialized_start=293
  _GETDETAILSRESPONSE._serialized_end=467
  _GETENVIRONMENTDETAILSREQUEST._serialized_start=469
  _GETENVIRONMENTDETAILSREQUEST._serialized_end=499
  _GETENVIRONMENTDETAILSRESPONSE._serialized_start=501
  _GETENVIRONMENTDETAILSRESPONSE._serialized_end=616
  _GETCLOUDCREDENTIALSREQUEST._serialized_start=618
  _GETCLOUDCREDENTIALSREQUEST._serialized_end=691
  _GETCLOUDCREDENTIALSRESPONSE._serialized_start=693
  _GETCLOUDCREDENTIALSRESPONSE._serialized_end=810
  _AUTHENTICATEDUSER._serialized_start=813
  _AUTHENTICATEDUSER._serialized_end=1312
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/secret_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.secret.v0 import secret_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/admiral/secret/v0/secret_service.proto\x12\x16qwak.admiral.secret.v0\x1a#qwak/admiral/secret/v0/secret.proto\"g\n\x1bSetEnvironmentSecretRequest\x12H\n\x07options\x18\x01 \x01(\x0b\x32\x37.qwak.admiral.secret.v0.SetUserEnvironmentSecretOptions\"\x1e\n\x1cSetEnvironmentSecretResponse\"i\n\x1e\x44\x65leteEnvironmentSecretRequest\x12G\n\nidentifier\x18\x01 \x01(\x0b\x32\x33.qwak.admiral.secret.v0.EnvironmentSecretIdentifier\"!\n\x1f\x44\x65leteEnvironmentSecretResponse\"\x1b\n\x19ListAccountSecretsRequest\"]\n\x1aListAccountSecretsResponse\x12?\n\x0f\x61\x63\x63ount_secrets\x18\x01 \x01(\x0b\x32&.qwak.admiral.secret.v0.AccountSecrets2\x9d\x03\n\rSecretService\x12\x81\x01\n\x14SetEnvironmentSecret\x12\x33.qwak.admiral.secret.v0.SetEnvironmentSecretRequest\x1a\x34.qwak.admiral.secret.v0.SetEnvironmentSecretResponse\x12\x8a\x01\n\x17\x44\x65leteEnvironmentSecret\x12\x36.qwak.admiral.secret.v0.DeleteEnvironmentSecretRequest\x1a\x37.qwak.admiral.secret.v0.DeleteEnvironmentSecretResponse\x12{\n\x12ListAccountSecrets\x12\x31.qwak.admiral.secret.v0.ListAccountSecretsRequest\x1a\x32.qwak.admiral.secret.v0.ListAccountSecretsResponseB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')



_SETENVIRONMENTSECRETREQUEST = DESCRIPTOR.message_types_by_name['SetEnvironmentSecretRequest']
_SETENVIRONMENTSECRETRESPONSE = DESCRIPTOR.message_types_by_name['SetEnvironmentSecretResponse']
_DELETEENVIRONMENTSECRETREQUEST = DESCRIPTOR.message_types_by_name['DeleteEnvironmentSecretRequest']
_DELETEENVIRONMENTSECRETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEnvironmentSecretResponse']
_LISTACCOUNTSECRETSREQUEST = DESCRIPTOR.message_types_by_name['ListAccountSecretsRequest']
_LISTACCOUNTSECRETSRESPONSE = DESCRIPTOR.message_types_by_name['ListAccountSecretsResponse']
SetEnvironmentSecretRequest = _reflection.GeneratedProtocolMessageType('SetEnvironmentSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETENVIRONMENTSECRETREQUEST,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetEnvironmentSecretRequest)
  })
_sym_db.RegisterMessage(SetEnvironmentSecretRequest)

SetEnvironmentSecretResponse = _reflection.GeneratedProtocolMessageType('SetEnvironmentSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETENVIRONMENTSECRETRESPONSE,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.SetEnvironmentSecretResponse)
  })
_sym_db.RegisterMessage(SetEnvironmentSecretResponse)

DeleteEnvironmentSecretRequest = _reflection.GeneratedProtocolMessageType('DeleteEnvironmentSecretRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENVIRONMENTSECRETREQUEST,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.DeleteEnvironmentSecretRequest)
  })
_sym_db.RegisterMessage(DeleteEnvironmentSecretRequest)

DeleteEnvironmentSecretResponse = _reflection.GeneratedProtocolMessageType('DeleteEnvironmentSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENVIRONMENTSECRETRESPONSE,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.DeleteEnvironmentSecretResponse)
  })
_sym_db.RegisterMessage(DeleteEnvironmentSecretResponse)

ListAccountSecretsRequest = _reflection.GeneratedProtocolMessageType('ListAccountSecretsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSECRETSREQUEST,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.ListAccountSecretsRequest)
  })
_sym_db.RegisterMessage(ListAccountSecretsRequest)

ListAccountSecretsResponse = _reflection.GeneratedProtocolMessageType('ListAccountSecretsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSECRETSRESPONSE,
  '__module__' : 'qwak.admiral.secret.v0.secret_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.secret.v0.ListAccountSecretsResponse)
  })
_sym_db.RegisterMessage(ListAccountSecretsResponse)

_SECRETSERVICE = DESCRIPTOR.services_by_name['SecretService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _SETENVIRONMENTSECRETREQUEST._serialized_start=108
  _SETENVIRONMENTSECRETREQUEST._serialized_end=211
  _SETENVIRONMENTSECRETRESPONSE._serialized_start=213
  _SETENVIRONMENTSECRETRESPONSE._serialized_end=243
  _DELETEENVIRONMENTSECRETREQUEST._serialized_start=245
  _DELETEENVIRONMENTSECRETREQUEST._serialized_end=350
  _DELETEENVIRONMENTSECRETRESPONSE._serialized_start=352
  _DELETEENVIRONMENTSECRETRESPONSE._serialized_end=385
  _LISTACCOUNTSECRETSREQUEST._serialized_start=387
  _LISTACCOUNTSECRETSREQUEST._serialized_end=414
  _LISTACCOUNTSECRETSRESPONSE._serialized_start=416
  _LISTACCOUNTSECRETSRESPONSE._serialized_end=509
  _SECRETSERVICE._serialized_start=512
  _SECRETSERVICE._serialized_end=925
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.offline.serving.v1 import offline_serving_async_service_pb2 as qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2


class FeatureStoreOfflineServingAsyncServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFileUploadUrl = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFileUploadUrl',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.FromString,
                )
        self.GetFeatureValues = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValues',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.FromString,
                )
        self.GetFeatureValuesInRange = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesInRange',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.FromString,
                )
        self.GetFeatureValuesResult = channel.unary_unary(
                '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesResult',
                request_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.SerializeToString,
                response_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.FromString,
                )


class FeatureStoreOfflineServingAsyncServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFileUploadUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValuesInRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureValuesResult(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureStoreOfflineServingAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFileUploadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFileUploadUrl,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.SerializeToString,
            ),
            'GetFeatureValues': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValues,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.SerializeToString,
            ),
            'GetFeatureValuesInRange': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValuesInRange,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.SerializeToString,
            ),
            'GetFeatureValuesResult': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureValuesResult,
                    request_deserializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.FromString,
                    response_serializer=qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureStoreOfflineServingAsyncService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFileUploadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFileUploadUrl',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFileUploadUrlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValues',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValuesInRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesInRange',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesInRangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureValuesResult(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.offline.serving.v1.FeatureStoreOfflineServingAsyncService/GetFeatureValuesResult',
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultRequest.SerializeToString,
            qwak_dot_offline_dot_serving_dot_v1_dot_offline__serving__async__service__pb2.GetFeatureValuesResultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.file_versioning.file_versioning_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RegisterFileTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_TAG_SPEC_FIELD_NUMBER: builtins.int
    @property
    def file_tag_spec(self) -> qwak.file_versioning.file_versioning_pb2.FileTagSpec: ...
    def __init__(
        self,
        *,
        file_tag_spec: qwak.file_versioning.file_versioning_pb2.FileTagSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file_tag_spec", b"file_tag_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_tag_spec", b"file_tag_spec"]) -> None: ...

global___RegisterFileTagRequest = RegisterFileTagRequest

class RegisterFileTagResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterFileTagResponse = RegisterFileTagResponse

class GetModelFileTagsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id to get file tags for"""
    build_id: builtins.str
    """The build id to get file tags for"""
    @property
    def filter(self) -> qwak.file_versioning.file_versioning_pb2.FileTagFilter:
        """The filter to apply to the file tags"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        filter: qwak.file_versioning.file_versioning_pb2.FileTagFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "filter", b"filter", "model_id", b"model_id"]) -> None: ...

global___GetModelFileTagsRequest = GetModelFileTagsRequest

class GetModelFileTagsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_TAGS_FIELD_NUMBER: builtins.int
    @property
    def file_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.file_versioning.file_versioning_pb2.FileTagSpec]: ...
    def __init__(
        self,
        *,
        file_tags: collections.abc.Iterable[qwak.file_versioning.file_versioning_pb2.FileTagSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_tags", b"file_tags"]) -> None: ...

global___GetModelFileTagsResponse = GetModelFileTagsResponse



from _qwak_proto.qwak.admiral.secret.v0.secret_pb2 import (
    EnvironmentSecretIdentifier,
    SystemSecretValue,
)
from _qwak_proto.qwak.admiral.secret.v0.system_secret_service_pb2 import (
    GetSystemSecretRequest,
    GetSystemSecretResponse,
)
from _qwak_proto.qwak.admiral.secret.v0.system_secret_service_pb2_grpc import (
    SystemSecretServiceStub,
)
from dependency_injector.wiring import Provide, inject
from qwak.inner.di_configuration import QwakContainer


class SystemSecretClient:
    @inject
    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._grpc_client: SystemSecretServiceStub = SystemSecretServiceStub(
            grpc_channel
        )

    def get_system_secret(self, name: str, env_id: str) -> SystemSecretValue:
        response: GetSystemSecretResponse = self._grpc_client.GetSystemSecret(
            GetSystemSecretRequest(
                identifier=EnvironmentSecretIdentifier(name=name, environment_id=env_id)
            )
        )

        return response.secret_definition.spec.value



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.execution.v1.backfill_pb2
import qwak.execution.v1.batch_pb2
import qwak.execution.v1.deletion_pb2
import qwak.execution.v1.streaming_aggregation_pb2
import qwak.execution.v1.streaming_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExecutionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExecutionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExecutionStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXECUTION_STATUS_INVALID: _ExecutionStatus.ValueType  # 0
    EXECUTION_STATUS_QUEUED: _ExecutionStatus.ValueType  # 1
    EXECUTION_STATUS_PENDING: _ExecutionStatus.ValueType  # 2
    EXECUTION_STATUS_RUNNING: _ExecutionStatus.ValueType  # 3
    EXECUTION_STATUS_COMPLETED: _ExecutionStatus.ValueType  # 4
    EXECUTION_STATUS_FAILED: _ExecutionStatus.ValueType  # 5
    EXECUTION_STATUS_CANCELLED: _ExecutionStatus.ValueType  # 6
    EXECUTION_STATUS_SUBMITTED: _ExecutionStatus.ValueType  # 7
    EXECUTION_STATUS_FAILED_SUBMISSION: _ExecutionStatus.ValueType  # 8
    EXECUTION_STATUS_SKIPPED: _ExecutionStatus.ValueType  # 9

class ExecutionStatus(_ExecutionStatus, metaclass=_ExecutionStatusEnumTypeWrapper): ...

EXECUTION_STATUS_INVALID: ExecutionStatus.ValueType  # 0
EXECUTION_STATUS_QUEUED: ExecutionStatus.ValueType  # 1
EXECUTION_STATUS_PENDING: ExecutionStatus.ValueType  # 2
EXECUTION_STATUS_RUNNING: ExecutionStatus.ValueType  # 3
EXECUTION_STATUS_COMPLETED: ExecutionStatus.ValueType  # 4
EXECUTION_STATUS_FAILED: ExecutionStatus.ValueType  # 5
EXECUTION_STATUS_CANCELLED: ExecutionStatus.ValueType  # 6
EXECUTION_STATUS_SUBMITTED: ExecutionStatus.ValueType  # 7
EXECUTION_STATUS_FAILED_SUBMISSION: ExecutionStatus.ValueType  # 8
EXECUTION_STATUS_SKIPPED: ExecutionStatus.ValueType  # 9
global___ExecutionStatus = ExecutionStatus

class ExecutionEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    EXECUTION_ID_FIELD_NUMBER: builtins.int
    EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    SUBMITTED_AT_FIELD_NUMBER: builtins.int
    SUBMITTED_BY_FIELD_NUMBER: builtins.int
    TRIGGERED_AT_FIELD_NUMBER: builtins.int
    ENDED_AT_FIELD_NUMBER: builtins.int
    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    BATCH_INGESTION_FIELD_NUMBER: builtins.int
    FEATURESET_DELETION_FIELD_NUMBER: builtins.int
    ONLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    OFFLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    ROW_LEVEL_STREAMING_AGGREGATION_INGESTION_FIELD_NUMBER: builtins.int
    COMPACTION_STREAMING_AGGREGATION_INGESTION_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_BACKFILL_INGESTION_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    execution_id: builtins.str
    execution_status: global___ExecutionStatus.ValueType
    @property
    def submitted_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def submitted_by(self) -> global___InvokerDetails: ...
    @property
    def triggered_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def ended_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec:
        """Batch Backfill"""
    @property
    def batch_ingestion(self) -> qwak.execution.v1.batch_pb2.BatchIngestion:
        """"Regular" batch ingestion"""
    @property
    def featureset_deletion(self) -> qwak.execution.v1.deletion_pb2.FeaturesetDeletion:
        """Featureset deletion"""
    @property
    def online_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion:
        """Online Streaming Ingestion"""
    @property
    def offline_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion:
        """Offline Streaming Ingestion"""
    @property
    def row_level_streaming_aggregation_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion:
        """Streaming Aggregation RowLevel"""
    @property
    def compaction_streaming_aggregation_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion:
        """Streaming Aggregation Compaction"""
    @property
    def streaming_aggregation_backfill_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion:
        """Streaming Aggregation Backfill"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        execution_id: builtins.str = ...,
        execution_status: global___ExecutionStatus.ValueType = ...,
        submitted_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        submitted_by: global___InvokerDetails | None = ...,
        triggered_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ended_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
        batch_ingestion: qwak.execution.v1.batch_pb2.BatchIngestion | None = ...,
        featureset_deletion: qwak.execution.v1.deletion_pb2.FeaturesetDeletion | None = ...,
        online_streaming_ingestion: qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion | None = ...,
        offline_streaming_ingestion: qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion | None = ...,
        row_level_streaming_aggregation_ingestion: qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion | None = ...,
        compaction_streaming_aggregation_ingestion: qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion | None = ...,
        streaming_aggregation_backfill_ingestion: qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "batch_ingestion", b"batch_ingestion", "compaction_streaming_aggregation_ingestion", b"compaction_streaming_aggregation_ingestion", "ended_at", b"ended_at", "execution_type", b"execution_type", "featureset_deletion", b"featureset_deletion", "offline_streaming_ingestion", b"offline_streaming_ingestion", "online_streaming_ingestion", b"online_streaming_ingestion", "row_level_streaming_aggregation_ingestion", b"row_level_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion", b"streaming_aggregation_backfill_ingestion", "submitted_at", b"submitted_at", "submitted_by", b"submitted_by", "triggered_at", b"triggered_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec", "batch_ingestion", b"batch_ingestion", "compaction_streaming_aggregation_ingestion", b"compaction_streaming_aggregation_ingestion", "ended_at", b"ended_at", "execution_id", b"execution_id", "execution_status", b"execution_status", "execution_type", b"execution_type", "featureset_deletion", b"featureset_deletion", "featureset_id", b"featureset_id", "offline_streaming_ingestion", b"offline_streaming_ingestion", "online_streaming_ingestion", b"online_streaming_ingestion", "row_level_streaming_aggregation_ingestion", b"row_level_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion", b"streaming_aggregation_backfill_ingestion", "submitted_at", b"submitted_at", "submitted_by", b"submitted_by", "triggered_at", b"triggered_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["execution_type", b"execution_type"]) -> typing_extensions.Literal["backfill_spec", "batch_ingestion", "featureset_deletion", "online_streaming_ingestion", "offline_streaming_ingestion", "row_level_streaming_aggregation_ingestion", "compaction_streaming_aggregation_ingestion", "streaming_aggregation_backfill_ingestion"] | None: ...

global___ExecutionEntry = ExecutionEntry

class InvokerDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_INVOKER_FIELD_NUMBER: builtins.int
    INTERNAL_INVOKER_FIELD_NUMBER: builtins.int
    @property
    def external_invoker(self) -> global___ExternalInvoker:
        """External Invoker - a user hit RunNow etc."""
    @property
    def internal_invoker(self) -> global___InternalInvoker:
        """Internal Invoker - a Scheduled run"""
    def __init__(
        self,
        *,
        external_invoker: global___ExternalInvoker | None = ...,
        internal_invoker: global___InternalInvoker | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["external_invoker", b"external_invoker", "internal_invoker", b"internal_invoker", "invoker_type", b"invoker_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_invoker", b"external_invoker", "internal_invoker", b"internal_invoker", "invoker_type", b"invoker_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["invoker_type", b"invoker_type"]) -> typing_extensions.Literal["external_invoker", "internal_invoker"] | None: ...

global___InvokerDetails = InvokerDetails

class ExternalInvoker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVOKER_EMAIL_FIELD_NUMBER: builtins.int
    invoker_email: builtins.str
    def __init__(
        self,
        *,
        invoker_email: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invoker_email", b"invoker_email"]) -> None: ...

global___ExternalInvoker = ExternalInvoker

class InternalInvoker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___InternalInvoker = InternalInvoker



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/auto_scaling/v1/auto_scaling.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'qwak/auto_scaling/v1/auto_scaling.proto\x12\x14qwak.auto_scaling.v1\"\xaf\x01\n\x11\x41utoScalingConfig\x12\x19\n\x11min_replica_count\x18\x01 \x01(\x05\x12\x19\n\x11max_replica_count\x18\x02 \x01(\x05\x12\x18\n\x10polling_interval\x18\x03 \x01(\x05\x12\x18\n\x10\x63ool_down_period\x18\x04 \x01(\x05\x12\x30\n\x08triggers\x18\x05 \x01(\x0b\x32\x1e.qwak.auto_scaling.v1.Triggers\";\n\x08Triggers\x12/\n\x08triggers\x18\x01 \x03(\x0b\x32\x1d.qwak.auto_scaling.v1.Trigger\"`\n\x07Trigger\x12\x45\n\x12prometheus_trigger\x18\x01 \x01(\x0b\x32\'.qwak.auto_scaling.v1.PrometheusTriggerH\x00\x42\x0e\n\x0ctrigger_type\"[\n\x11PrometheusTrigger\x12\x33\n\nquery_spec\x18\x01 \x01(\x0b\x32\x1f.qwak.auto_scaling.v1.QuerySpec\x12\x11\n\tthreshold\x18\x02 \x01(\x05\"\xac\x01\n\tQuerySpec\x12\x35\n\x0bmetric_type\x18\x01 \x01(\x0e\x32 .qwak.auto_scaling.v1.MetricType\x12?\n\x10\x61ggregation_type\x18\x02 \x01(\x0e\x32%.qwak.auto_scaling.v1.AggregationType\x12\x13\n\x0btime_period\x18\x03 \x01(\x05\x12\x12\n\nerror_code\x18\x04 \x01(\t*\xba\x01\n\nMetricType\x12\x19\n\x15METRIC_TYPE_NOT_VALID\x10\x00\x12\x13\n\x0fMETRIC_TYPE_CPU\x10\x01\x12\x16\n\x12METRIC_TYPE_MEMORY\x10\x02\x12\x17\n\x13METRIC_TYPE_LATENCY\x10\x03\x12\x13\n\x0fMETRIC_TYPE_GPU\x10\x04\x12\x1a\n\x16METRIC_TYPE_ERROR_RATE\x10\x05\x12\x1a\n\x16METRIC_TYPE_THROUGHPUT\x10\x06*\x85\x02\n\x0f\x41ggregationType\x12\x1e\n\x1a\x41GGREGATION_TYPE_NOT_VALID\x10\x00\x12\x18\n\x14\x41GGREGATION_TYPE_MIN\x10\x01\x12\x18\n\x14\x41GGREGATION_TYPE_MAX\x10\x02\x12\x1c\n\x18\x41GGREGATION_TYPE_AVERAGE\x10\x03\x12\x18\n\x14\x41GGREGATION_TYPE_SUM\x10\x04\x12\x18\n\x14\x41GGREGATION_TYPE_P50\x10\x05\x12\x18\n\x14\x41GGREGATION_TYPE_P90\x10\x06\x12\x18\n\x14\x41GGREGATION_TYPE_P95\x10\x07\x12\x18\n\x14\x41GGREGATION_TYPE_P99\x10\x08\x42K\n%com.qwak.ai.management.deployment.apiP\x01Z qwak/auto_scaling/v1;autoscalingb\x06proto3')

_METRICTYPE = DESCRIPTOR.enum_types_by_name['MetricType']
MetricType = enum_type_wrapper.EnumTypeWrapper(_METRICTYPE)
_AGGREGATIONTYPE = DESCRIPTOR.enum_types_by_name['AggregationType']
AggregationType = enum_type_wrapper.EnumTypeWrapper(_AGGREGATIONTYPE)
METRIC_TYPE_NOT_VALID = 0
METRIC_TYPE_CPU = 1
METRIC_TYPE_MEMORY = 2
METRIC_TYPE_LATENCY = 3
METRIC_TYPE_GPU = 4
METRIC_TYPE_ERROR_RATE = 5
METRIC_TYPE_THROUGHPUT = 6
AGGREGATION_TYPE_NOT_VALID = 0
AGGREGATION_TYPE_MIN = 1
AGGREGATION_TYPE_MAX = 2
AGGREGATION_TYPE_AVERAGE = 3
AGGREGATION_TYPE_SUM = 4
AGGREGATION_TYPE_P50 = 5
AGGREGATION_TYPE_P90 = 6
AGGREGATION_TYPE_P95 = 7
AGGREGATION_TYPE_P99 = 8


_AUTOSCALINGCONFIG = DESCRIPTOR.message_types_by_name['AutoScalingConfig']
_TRIGGERS = DESCRIPTOR.message_types_by_name['Triggers']
_TRIGGER = DESCRIPTOR.message_types_by_name['Trigger']
_PROMETHEUSTRIGGER = DESCRIPTOR.message_types_by_name['PrometheusTrigger']
_QUERYSPEC = DESCRIPTOR.message_types_by_name['QuerySpec']
AutoScalingConfig = _reflection.GeneratedProtocolMessageType('AutoScalingConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUTOSCALINGCONFIG,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.AutoScalingConfig)
  })
_sym_db.RegisterMessage(AutoScalingConfig)

Triggers = _reflection.GeneratedProtocolMessageType('Triggers', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERS,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.Triggers)
  })
_sym_db.RegisterMessage(Triggers)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

PrometheusTrigger = _reflection.GeneratedProtocolMessageType('PrometheusTrigger', (_message.Message,), {
  'DESCRIPTOR' : _PROMETHEUSTRIGGER,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.PrometheusTrigger)
  })
_sym_db.RegisterMessage(PrometheusTrigger)

QuerySpec = _reflection.GeneratedProtocolMessageType('QuerySpec', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPEC,
  '__module__' : 'qwak.auto_scaling.v1.auto_scaling_pb2'
  # @@protoc_insertion_point(class_scope:qwak.auto_scaling.v1.QuerySpec)
  })
_sym_db.RegisterMessage(QuerySpec)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z qwak/auto_scaling/v1;autoscaling'
  _METRICTYPE._serialized_start=671
  _METRICTYPE._serialized_end=857
  _AGGREGATIONTYPE._serialized_start=860
  _AGGREGATIONTYPE._serialized_end=1121
  _AUTOSCALINGCONFIG._serialized_start=66
  _AUTOSCALINGCONFIG._serialized_end=241
  _TRIGGERS._serialized_start=243
  _TRIGGERS._serialized_end=302
  _TRIGGER._serialized_start=304
  _TRIGGER._serialized_end=400
  _PROMETHEUSTRIGGER._serialized_start=402
  _PROMETHEUSTRIGGER._serialized_end=493
  _QUERYSPEC._serialized_start=496
  _QUERYSPEC._serialized_end=668
# @@protoc_insertion_point(module_scope)



from _qwak_proto.qwak.execution.v1.backfill_pb2 import BackfillSpec
from _qwak_proto.qwak.execution.v1.batch_pb2 import BatchIngestion
from _qwak_proto.qwak.execution.v1.execution_service_pb2 import (
    GetExecutionEntryRequest,
    GetExecutionEntryResponse,
    GetExecutionStatusRequest,
    GetExecutionStatusResponse,
    TriggerBackfillRequest,
    TriggerBackfillResponse,
    TriggerBatchFeaturesetRequest,
    TriggerBatchFeaturesetResponse,
)
from _qwak_proto.qwak.execution.v1.execution_service_pb2_grpc import (
    FeatureStoreExecutionServiceStub,
)
from dependency_injector.wiring import Provide
from grpc import RpcError
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class ExecutionManagementClient:
    """
    Used for interacting with the execution manager endpoints
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._feature_store_execution_service = FeatureStoreExecutionServiceStub(
            grpc_channel
        )

    def trigger_batch_backfill(
        self, batch_backfill_spec: BackfillSpec
    ) -> TriggerBackfillResponse:
        """
        Receives a configured batch back-fill spec proto and triggers a batch back-fill against the execution manager
        @param batch_backfill_spec: a proto message containing the backfilll specification details
        @type batch_backfill_spec: BackfillSpec
        @return: response object from the execution manager
        @rtype: TriggerBackfillResponse
        """
        try:
            return self._feature_store_execution_service.TriggerBatchBackfill(
                TriggerBackfillRequest(backfill_spec=batch_backfill_spec)
            )
        except RpcError as e:
            raise QwakException(
                f"Failed to trigger batch backfill job, error encountered {e}"
            )

    def trigger_batch_featureset(
        self, batch_ingestion: BatchIngestion
    ) -> TriggerBatchFeaturesetResponse:
        """
        Receives a configured batch ingestion proto and triggers a batch job against the execution manager. This can be
        used both for manual and scheduled batch job executions.
        @param batch_ingestion: a proto message containing the batch job specification
        @type batch_ingestion: BatchIngestion
        @return: response object from the execution manager
        @rtype: TriggerBatchFeaturesetResponse
        """
        try:
            return self._feature_store_execution_service.TriggerBatchFeatureset(
                TriggerBatchFeaturesetRequest(batch_ingestion=batch_ingestion)
            )
        except RpcError as e:
            raise QwakException(f"Failed to trigger batch job, error encountered {e}")

    def get_execution_status(self, execution_id: str) -> GetExecutionStatusResponse:
        """

        @param execution_id: the execution id for which we're querying the execution status
        @type execution_id: str
        @return: response received from the execution manager
        @rtype: GetExecutionStatusResponse
        """
        try:
            return self._feature_store_execution_service.GetExecutionStatus(
                GetExecutionStatusRequest(execution_id=execution_id)
            )
        except RpcError as e:
            raise QwakException(
                f"Failed to get execution status, error encountered {e}"
            )

    def get_execution_entry(self, execution_id: str) -> GetExecutionEntryResponse:
        """

        @param execution_id: the execution id for which we're querying the execution status
        @type execution_id: str
        @return: response received from the execution manager
        @rtype: GetExecutionStatusResponse
        """
        try:
            return self._feature_store_execution_service.GetExecutionEntry(
                GetExecutionEntryRequest(execution_id=execution_id)
            )
        except RpcError as e:
            raise QwakException(f"Failed to get execution entry, error encountered {e}")
